@@ -1,7 +1,7 @@
 package Log::Any::For::Builtins;
 
-our $DATE = '2015-08-17'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $DATE = '2016-04-17'; # DATE
+our $VERSION = '0.12'; # VERSION
 
 use 5.010001;
 use strict;
@@ -25,20 +25,20 @@ sub system {
     $res;
 }
 
-sub my_qx {
+sub readpipe {
     my $arg = join " ", @_;
     if ($log->is_trace) {
-        $log->tracef("my_qx(): %s", $arg);
+        $log->tracef("readpipe(): %s", $arg);
     }
     my $wa = wantarray;
     my $output;
     my @output;
     if ($wa) { @output = qx($arg) } else { $output = qx($arg) }
     if ($log->is_trace) {
-        $log->tracef("my_qx() child error: %d (%s)",
+        $log->tracef("readpipe() child error: %d (%s)",
                      $?, explain_child_error()) if $?;
         if ($wa) { $output = join("", @output) }
-        $log->tracef("my_qx() output (%d bytes%s): %s",
+        $log->tracef("readpipe() output (%d bytes%s): %s",
                      length($output),
                      (length($output) > $Max_Log_Output ?
                          ", $Max_Log_Output shown" : ""),
@@ -57,7 +57,10 @@ sub import {
         if ($arg eq 'system') {
             *{"$caller\::system"} = \&system;
         } elsif ($arg eq 'my_qx') {
-            *{"$caller\::my_qx"} = \&my_qx;
+            # back compat
+            *{"$caller\::my_qx"} = \&readpipe;
+        } elsif ($arg eq 'readpipe') {
+            *{"$caller\::readpipe"} = \&readpipe;
         } else {
             die "$arg is not exported by ".__PACKAGE__;
         }
@@ -79,22 +82,22 @@ Log::Any::For::Builtins - (DEPRECATED) Log builtin functions
 
 =head1 VERSION
 
-This document describes version 0.11 of Log::Any::For::Builtins (from Perl distribution Builtin-Logged), released on 2015-08-17.
+This document describes version 0.12 of Log::Any::For::Builtins (from Perl distribution Builtin-Logged), released on 2016-04-17.
 
 =head1 SYNOPSIS
 
- use Log::Any::For::Builtins qw(system my_qx);
+ use Log::Any::For::Builtins qw(system readpipe);
 
  system "blah ...";
- my $out = my_qx("blah ...");
+ my $out = `blah ...`;
 
 When run, it might produce logs like:
 
  [TRACE] system(): blah ...
  [TRACE] system() child error: 256 (exited with value 1)
- [TRACE] my_qx(): blah ...
- [TRACE] my_qx() child error: 0 (exited with value 0)
- [TRACE] my_qx() output (200 bytes): Command output...
+ [TRACE] readpipe(): blah ...
+ [TRACE] readpipe() child error: 0 (exited with value 0)
+ [TRACE] readpipe() output (200 bytes): Command output...
 
 =head1 DESCRIPTION
 
@@ -112,21 +115,15 @@ statements from L<Log::Any>. The log statements are at C<trace> level.
 
 =item * system
 
-=item * my_qx
+Will override system() with a version that does logging.
 
-Will provide my_qx(). Use this instead of qx() or backtick. Perl currently does
-not provide an easy way to override/overload qx().
+=item * readpipe
+
+Will override readpipe() (which means the backtick operator also) with a version
+that does logging.
 
 =back
 
-=head1 VARIABLES
-
-=head1 SEE ALSO
-
-L<Log::Any>
-
-Other Log::Any::For::* modules.
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Builtin-Logged>.
@@ -143,13 +140,19 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Log::Any>
+
+Other Log::Any::For::* modules.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
